@@ -16,7 +16,7 @@ from . import dataset
 from . import analytics
 from . import pipeline
 from . import error_handlers
-from . import platform_insights
+# from . import platform_insights
 from . import integration
 
 
@@ -32,4 +32,4 @@ from . import integration
 # log.addHandler(_ch)
 # https://dev.to/joaomcteixeira/setting-up-python-logging-for-a-library-app-6ml
 
-__version__ = "0.2.4"
+__version__ = "0.2.7"
