@@ -11,7 +11,7 @@ from typing import Literal
 __all__ = ['api_prefix', 'argus_prefix', 'DATETIME_COL_FMT', 'DEPLOY_TYPE', 'EXPECTED_DELIVERY', 'WORK_ORDER_PRIORITY',
            'WORK_ORDER_STATUS', 'WORK_ORDER_CATEGORY', 'ERROR_TYPE', 'MAPPING_ENTITIES', 'QUEUE_NAME', 'QUERY_LANGUAGE',
            'ACCOUNT', 'PROCESS_STATUS', 'AUTH_ENDPOINT_DEV', 'AUTH_ENDPOINT_PROD', 'SCHEDULE_TIMEZONE',
-           'SWITCH_ENVIRONMENT']
+           'SWITCH_ENVIRONMENT', 'INTEGRATION_SETTINGS_EDITORS']
 
 # api_prefix = "http://localhost:7071/api/SwitchApi/"
 api_prefix = "https://pivotstreams.azurewebsites.net/api/SwitchApi/"
@@ -31,14 +31,15 @@ DATETIME_COL_FMT = Literal['DateTime', 'Date', 'Time']
 
 EXPECTED_DELIVERY = Literal['15min', 'Hourly', 'Daily', 'Weekly', 'Monthly', 'Quarterly']
 
-DEPLOY_TYPE = Literal['ftp', 'email', 'timer']
+# deploy_type 'File' for (FTP. Email, Upload)
+DEPLOY_TYPE = Literal['Email', 'Ftp', 'Upload', 'Timer']
 
 ACCOUNT = Literal['SwitchStorage', 'SwitchContainer', 'Argus', 'DataIngestion']
 
 QUERY_LANGUAGE = Literal['sql', 'kql']
 
 ERROR_TYPE = Literal['DateTime', 'MissingDevices', 'NonNumeric', 'MissingRequiredField(s)', 'MissingSite(s)',
-                     'DuplicateRecords', 'MissingSensors', 'UnableToReadFile', 'InvalidFileType']
+                     'DuplicateRecords', 'MissingSensors', 'UnableToReadFile', 'InvalidFileType', 'InvalidInputSettings']
 
 PROCESS_STATUS = Literal['ActionRequired', 'Failed']
 
