@@ -9,10 +9,11 @@ A module for interacting with Data Sets from the Switch Automation platform.
 """
 import pandas
 import requests
-from .._utils._constants import api_prefix
-from .._utils._utils import ApiInputs
 import logging
 import sys
+from io import StringIO
+from .._utils._utils import ApiInputs
+
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -45,7 +46,7 @@ def get_folders(api_inputs: ApiInputs, folder_type="dataset"):
 
     """
 
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -91,17 +92,19 @@ def get_datasets_list(api_inputs: ApiInputs, include_path: bool = False, path_pr
         (response, df) - Returns the response status of the call & a dataframe containing the data returned by the call.
 
     """
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
     payload = {}
     headers = api_inputs.api_headers.default
 
-    if(path_prefix != "*"):
-        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/datasets?pathprefix={path_prefix.replace('/', '|')}&includepath={str(include_path)}"
+    if path_prefix != "*":
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/datasets?pathprefix=" \
+              f"{path_prefix.replace('/', '|')}&includepath={str(include_path)}"
     else:
-        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/datasets?includepath={str(include_path)}"
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/datasets?includepath=" \
+              f"{str(include_path)}"
 
     logger.info("Sending request: GET %s", url)
 
@@ -141,7 +144,7 @@ def get_data(api_inputs: ApiInputs, dataset_id, parameters: dict = None):
         (response, df) - Returns the response status of the call & a dataframe containing the data returned by the call.
     """
 
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -163,7 +166,7 @@ def get_data(api_inputs: ApiInputs, dataset_id, parameters: dict = None):
         logger.error('DataSets: no data returned for this call. %s', response.request.url)
         return response_status, pandas.DataFrame()
 
-    df = pandas.read_json(response.text, dtype=False)
+    df = pandas.read_json(StringIO(response.text), dtype=False)
     logger.info("API Call successful.")
 
     return response_status, df
