@@ -21,8 +21,7 @@ The validate_datetime() function can be used to validate the datetime column(s)
 
 >>> import pandas as pd
 >>> import switch_api as sw
->>> api_inputs = sw.initialize(user_id, api_project_id) # set api_project_id to the relevant portfolio and user_id to
-                                                       # your own user identifier
+>>> api_inputs = sw.initialize(api_project_id=api_project_id) # set api_project_id to the relevant portfolio
 >>> test_df = pd.DataFrame({'DateTime':['2021-06-01 00:00:00', '2021-06-01 00:15:00', '', '2021-06-01 00:45:00'],
 ... 'Value':[10, 20, 30, 40], 'device_id':['xyz', 'xyz', 'xyz', 'xyz']})
 >>> df_invalid_datetime, df = validate_datetime(df=test_df, datetime_col=['DateTime'], dt_fmt='%Y-%m-%d %H:%M:%S')
@@ -37,7 +36,7 @@ import requests
 import sys
 import json
 from typing import Optional, List, Union
-from .._utils._constants import api_prefix, ERROR_TYPE, PROCESS_STATUS
+from .._utils._constants import ERROR_TYPE, PROCESS_STATUS
 from .._utils._utils import ApiInputs
 
 logger = logging.getLogger(__name__)
@@ -51,7 +50,7 @@ formatter = logging.Formatter('%(asctime)s  switch_api.%(module)s.%(funcName)s
 consoleHandler.setFormatter(formatter)
 
 
-def invalid_file_format(api_inputs: ApiInputs, schema: pandera.DataFrameSchema, raw_df: pandas.DataFrame, process_status: PROCESS_STATUS = 'Failed'):
+def invalid_file_format(api_inputs: ApiInputs, schema: pandera.DataFrameSchema, raw_df: pandas.DataFrame):
     """Validates the raw file format and posts any errors to data feed dashboard
 
     Parameters
@@ -69,13 +68,14 @@ def invalid_file_format(api_inputs: ApiInputs, schema: pandera.DataFrameSchema,
         Data frame containing the response from API after posting any errors to data feed dashboard.
 
     """
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
     headers = api_inputs.api_headers.default
 
     error_type = 'FileFormat'
+    process_status = 'Failed'
 
     try:
         schema.validate(raw_df, lazy=True)
@@ -103,7 +103,7 @@ def invalid_file_format(api_inputs: ApiInputs, schema: pandera.DataFrameSchema,
         return response_data_frame
 
 
-def post_errors(api_inputs: ApiInputs, errors_df: pandas.DataFrame, error_type: ERROR_TYPE,
+def post_errors(api_inputs: ApiInputs, errors: Union[pandas.DataFrame, str], error_type: ERROR_TYPE,
                 process_status: PROCESS_STATUS = 'ActionRequired'):
     """Post errors to the Data Feed Dashboard
 
@@ -113,8 +113,8 @@ def post_errors(api_inputs: ApiInputs, errors_df: pandas.DataFrame, error_type:
     ----------
     api_inputs : ApiInputs
         The object returned by call to initialize() function.
-    errors_df : pandas.DataFrame
-        The dataframe containing the rows with errors.
+    errors : Union[pandas.DataFrame, str]
+        The dataframe containing the row(s) with errors or a string describing the error(s).
     error_type : ERROR_TYPE
         The type of error being posted to Data Feed Dashboard.
     process_status: PROCESS_STATUS, optional
@@ -127,7 +127,7 @@ def post_errors(api_inputs: ApiInputs, errors_df: pandas.DataFrame, error_type:
         True or False indicating the success of the call
 
     """
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -148,11 +148,22 @@ def post_errors(api_inputs: ApiInputs, errors_df: pandas.DataFrame, error_type:
 
     headers = api_inputs.api_headers.default
 
-    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/{api_inputs.data_feed_id}/errors?status={process_status}&errorType={error_type}&statusId={api_inputs.data_feed_file_status_id}"
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/" \
+          f"{api_inputs.data_feed_id}/errors?status={process_status}&errorType={error_type}&statusId=" \
+          f"{api_inputs.data_feed_file_status_id}"
     logger.info("Sending request: POST %s", url)
 
+    payload = ""
+    if (isinstance(errors, pandas.DataFrame)):
+        payload = json.dumps(json.loads(errors.to_json(orient='table'))['data'])
+    elif (isinstance(errors, str)):
+        payload = errors
+    else:
+        logger.error('errors_content parameter must be set to either a type of pandas.DataFrame or string')
+        return False
+
     response = requests.post(url,
-                             data=json.dumps(json.loads(errors_df.to_json(orient='table'))['data']),
+                             data=payload,
                              headers=headers)
 
     response_status = '{} {}'.format(response.status_code, response.reason)
@@ -203,8 +214,7 @@ def validate_datetime(df: pandas.DataFrame, datetime_col: Union[str, List[str]],
 
     >>> import pandas as pd
     >>> import switch_api as sw
-    >>> api_inputs = sw.initialize(user_id, api_project_id) # set api_project_id to the relevant portfolio and user_id
-    ...                                                     # to your own user identifier
+    >>> api_inputs = sw.initialize(api_project_id = api_project_id) # set api_project_id to the relevant portfolio
     >>> test_df = pd.DataFrame({'DateTime':['2021-06-01 00:00:00', '2021-06-01 00:15:00', '', '2021-06-01 00:45:00'],
     ... 'Value':[10, 20, 30, 40], 'device_id':['xyz', 'xyz', 'xyz', 'xyz']})
     >>> df_invalid_datetime, df = validate_datetime(df=test_df, datetime_col=['DateTime'], dt_fmt='%Y-%m-%d %H:%M:%S')
