@@ -12,7 +12,7 @@ import requests
 import datetime
 import logging
 import sys
-from .._utils._constants import api_prefix  # , QUERY_LANGUAGE
+from .._utils._constants import SUPPORT_PAYLOAD_TYPE  # , QUERY_LANGUAGE
 from .._utils._utils import ApiInputs
 
 logger = logging.getLogger(__name__)
@@ -26,30 +26,6 @@ formatter = logging.Formatter('%(asctime)s  switch_api.%(module)s.%(funcName)s
 consoleHandler.setFormatter(formatter)
 
 
-def _adx_support(api_inputs: ApiInputs, build_sites=False, build_sensors=False):
-    adx_support_prefix = ''
-    if api_inputs.datacentre == 'AU':
-        adx_support_prefix = 'australiaeast'
-    elif api_inputs.datacentre == 'EA':
-        adx_support_prefix = 'australiaeast'
-    elif api_inputs.datacentre == 'US':
-        adx_support_prefix = 'centralus'
-
-    if adx_support_prefix == '':
-        logger.error('Invalid Data Centre: ' + api_inputs.datacentre)
-        return
-
-    if build_sites:
-        adx_support_url = 'https://adxsupport-' + adx_support_prefix + \
-                          '-prod.azurewebsites.net/api/sites?apiProjectId=' + api_inputs.api_project_id
-        requests.get(adx_support_url)
-
-    if build_sensors:
-        adx_support_url = 'https://adxsupport-' + adx_support_prefix + \
-                          '-prod.azurewebsites.net/api/sensors?apiProjectId=' + api_inputs.api_project_id
-        requests.get(adx_support_url)
-
-
 def _timezones(api_inputs: ApiInputs):
     """Get timezones
 
@@ -65,18 +41,16 @@ def _timezones(api_inputs: ApiInputs):
 
     """
     # payload = {}
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
+    headers = api_inputs.api_headers.default
 
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
     # upload Blobs to folder
-    url = api_prefix + "Timezones"
+    url = f"{api_inputs.api_base_url}/timezones/all"
+    logger.info("Sending request: GET %s", url)
+
     response = requests.request("GET", url, timeout=20, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
     if response.status_code != 200:
@@ -84,7 +58,7 @@ def _timezones(api_inputs: ApiInputs):
                      response.reason)
         return response_status, pandas.DataFrame()
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status, pandas.DataFrame()
 
     df = pandas.read_json(response.text, orient='index')
@@ -122,17 +96,15 @@ def _timezone_offsets(api_inputs: ApiInputs, date_from: datetime.date, date_to:
         "installationIds": installation_id_list
     }
 
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
-
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/TimeZoneOffsets"
+    headers = api_inputs.api_headers.default
+
+    url = f"{api_inputs.api_base_url}/timezones/offsets"
+    logger.info("Sending request: POST %s", url)
+
     response = requests.post(url, json=payload, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
     if response.status_code != 200:
@@ -140,9 +112,99 @@ def _timezone_offsets(api_inputs: ApiInputs, date_from: datetime.date, date_to:
                      response.reason)
         return response_status, pandas.DataFrame()
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status, pandas.DataFrame()
 
     response_data_frame = pandas.read_json(response.text)
 
     return response_data_frame
+
+
+def _upsert_entities_affected_count(api_inputs: ApiInputs, entities_affected_count: int):
+    """Updates data feed and data feed file status entities affected count.
+
+    Parameters
+    ----------
+    api_inputs : ApiInputs
+        Object returned by initialize() function.
+    entities_affected_count : int
+        Count of affected entities - i.e. how many records are being upserted, replaced or appended.
+
+    Returns
+    -------
+
+    """
+
+    if entities_affected_count is None:
+        entities_affected_count = 0
+
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
+        logger.error("You must call initialize() before using API.")
+        return pandas.DataFrame()
+
+    if (api_inputs.data_feed_id == '00000000-0000-0000-0000-000000000000' or
+            api_inputs.data_feed_file_status_id == '00000000-0000-0000-0000-000000000000'):
+        logger.error("Entities Affected Count can only be upserted when called in Production.")
+        return False
+
+    headers = api_inputs.api_headers.default
+
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/data-feed/" \
+          f"{api_inputs.data_feed_id}/file-status/{api_inputs.data_feed_file_status_id}/entities-affected/" \
+          f"{entities_affected_count}"
+
+    response = requests.request("PUT", url, timeout=20, headers=headers)
+
+    if response.status_code != 200:
+        logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
+                     response.reason)
+    elif response.status_code == 200:
+        logger.info("Entities Affected Count successfully upserted. ")
+
+
+def _adx_support(api_inputs: ApiInputs, payload_type: SUPPORT_PAYLOAD_TYPE):
+    """
+        Call ADX Support endpoint to trigger SQL->ADX sync
+
+    Parameters
+    ----------
+    api_inputs : ApiInputs
+        Object returned by initialize() function.
+    payload_type : SUPPORT_PAYLOAD_TYPE
+        Payload Type to sync ADX
+
+    Returns
+    -------
+
+
+    """
+    headers = api_inputs.api_headers.default
+
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
+        logger.error("You must call initialize() before using API.")
+        return pandas.DataFrame()
+
+    if payload_type == None:
+        logger.error("You must provide the ADX Support Payload Type to SYNC ADX.")
+        return pandas.DataFrame()
+
+    if not set([payload_type]).issubset(set(SUPPORT_PAYLOAD_TYPE.__args__)):
+        logger.error('payload_type parameter must be set to one of the allowed values defined by the '
+                     'SUPPORT_PAYLOAD_TYPE literal: %s', SUPPORT_PAYLOAD_TYPE.__args__)
+        return pandas.DataFrame()
+
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/adx/sync/{payload_type}"
+
+    response = requests.request("PUT", url, timeout=20, headers=headers)
+    response_status = '{} {}'.format(response.status_code, response.reason)
+    if response.status_code != 200:
+        logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
+                     response.reason)
+        return response_status, pandas.DataFrame()
+    elif len(response.text) == 0:
+        logger.error('No data returned for this API call. %s', response.request.url)
+        return response_status, pandas.DataFrame()
+
+    logger.info("API Call successful.")
+
+    return response_status, response.text
