@@ -14,7 +14,7 @@ import requests
 import logging
 import uuid
 from typing import Union
-from .._utils._constants import api_prefix, QUERY_LANGUAGE
+from .._utils._constants import QUERY_LANGUAGE
 from .._utils._utils import ApiInputs, _column_name_cap
 
 logger = logging.getLogger(__name__)
@@ -45,7 +45,7 @@ def get_operation_state(upload_id: uuid.UUID, api_inputs: ApiInputs):
 
     """
     # payload = {}
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -85,7 +85,7 @@ def load_data(dev_mode_path, api_inputs: ApiInputs):
     pandas.DataFrame
 
     """
-    if (api_inputs.api_projects_endpoint == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_projects_endpoint == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -111,7 +111,7 @@ def data_table_exists(table_name: str, api_inputs: ApiInputs):
 
     """
     # payload = {}
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -187,7 +187,7 @@ def get_sites(api_inputs: ApiInputs, include_tag_groups: Union[list, bool] = Fal
         "topCount": top_count,
     }
 
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -286,7 +286,7 @@ def get_device_sensors(api_inputs: ApiInputs, include_tag_groups: Union[list, bo
         "offset": offset
     }
 
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -331,7 +331,7 @@ def get_device_sensors(api_inputs: ApiInputs, include_tag_groups: Union[list, bo
             is_finished = True
             df_master = pandas.concat(df_data_chunks, ignore_index=True)
             df_master.rename(columns={"InstallationID": "InstallationId", "ObjectPropertyID": "ObjectPropertyId"},
-                           inplace=True)
+                             inplace=True)
             return df_master
 
     return df_master
@@ -359,7 +359,7 @@ def get_data(query_text, api_inputs: ApiInputs, query_language: QUERY_LANGUAGE =
         "queryLanguage": str(query_language)
     }
 
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -405,7 +405,7 @@ def get_states_by_country(api_inputs: ApiInputs, country: str):
 
         """
     # payload = {}
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -449,7 +449,7 @@ def get_templates(api_inputs: ApiInputs, object_property_type: str = None):
 
     """
     # payload = {}
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -459,7 +459,8 @@ def get_templates(api_inputs: ApiInputs, object_property_type: str = None):
     if object_property_type is None:
         url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/templates"
     elif object_property_type is not None:
-        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/templates?type={object_property_type}"
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/templates?type=" \
+              f"{object_property_type}"
 
     logger.info("Sending request: GET %s", url)
 
@@ -494,7 +495,7 @@ def get_tag_groups(api_inputs: ApiInputs):
 
     """
     # payload = {}
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -535,7 +536,7 @@ def get_metadata_keys(api_inputs: ApiInputs):
 
     """
     # payload = {}
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -578,7 +579,7 @@ def get_units_of_measure(api_inputs: ApiInputs, object_property_type: str = None
     """
     # payload = {}
 
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -589,7 +590,8 @@ def get_units_of_measure(api_inputs: ApiInputs, object_property_type: str = None
     if object_property_type is None:
         url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/units"
     elif object_property_type is not None:
-        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/units?type={object_property_type}"
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/units?type=" \
+              f"{object_property_type}"
 
     logger.info("Sending request: GET %s", url)
 
@@ -624,17 +626,18 @@ def get_equipment_classes(api_inputs: ApiInputs):
 
     """
     # payload = {}
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
     headers = api_inputs.api_headers.default
 
-    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/installation/00000000-0000-0000-0000-000000000000/equipment/integration-classes"
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/installation/" \
+          f"00000000-0000-0000-0000-000000000000/equipment/integration-classes"
 
     logger.info("Sending request: GET %s", url)
 
-    if (api_inputs.api_projects_endpoint == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_projects_endpoint == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
