@@ -16,7 +16,6 @@ import datetime
 import logging
 import uuid
 from .._utils._platform import _get_structure, Blob
-from .._utils._constants import api_prefix
 from .._utils._utils import (ApiInputs, _with_func_attrs, _column_name_cap, _work_order_schema,
                              DiscoveryIntegrationInput, convert_to_pascal_case)
 from ..integration._utils import _timezone_offsets, _upsert_entities_affected_count, _adx_support
@@ -35,10 +34,10 @@ consoleHandler.setFormatter(formatter)
 @_with_func_attrs(df_required_columns=['ApiProjectId', 'InstallationId', 'NetworkDeviceId', 'UserId', 'BatchNo',
                                        'DriverUniqueId', 'Timestamp', 'DiscoveredValue'],
                   df_optional_columns=['DriverDeviceType', 'ObjectPropertyTemplateName', 'UnitOfMeasureAbbrev',
-                                       'DeviceName', 'DisplayName', 'EquipmentType', 'EquipmentLabel',])
+                                       'DeviceName', 'DisplayName', 'EquipmentType', 'EquipmentLabel', ])
 def upsert_discovered_records(df: pandas.DataFrame, api_inputs: ApiInputs, discovery_properties_columns: list,
                               device_tag_columns: list = None, sensor_tag_columns: list = None,
-                              metadata_columns: list = None):  #, ontology_tag_columns: list = None):
+                              metadata_columns: list = None):  # , ontology_tag_columns: list = None):
     """Upsert discovered records to populate Build - Discovery & Selection UI.
 
     Parameters
@@ -75,7 +74,7 @@ def upsert_discovered_records(df: pandas.DataFrame, api_inputs: ApiInputs, disco
     required_columns = ['ApiProjectId', 'InstallationId', 'NetworkDeviceId', 'UserId', 'BatchNo', 'DriverUniqueId',
                         'Timestamp', 'DiscoveredValue']
     optional_columns = ['DriverDeviceType', 'ObjectPropertyTemplateName', 'UnitOfMeasureAbbrev', 'DeviceName',
-                        'DisplayName', 'EquipmentType', 'EquipmentLabel',]
+                        'DisplayName', 'EquipmentType', 'EquipmentLabel', ]
     proposed_columns = data_frame.columns.tolist()
 
     if not set(required_columns).issubset(proposed_columns):
@@ -90,8 +89,8 @@ def upsert_discovered_records(df: pandas.DataFrame, api_inputs: ApiInputs, disco
     if discovery_properties_columns is not None and not set(discovery_properties_columns).issubset(data_frame.columns):
         logger.exception('Missing expected discovery property column(s): %s',
                          set(discovery_properties_columns).difference(proposed_columns))
-        return 'Integration.upsert_discovered_records(): data_frame must contain the following tag columns: ' + ', '.join(
-            discovery_properties_columns)
+        return 'Integration.upsert_discovered_records(): data_frame must contain the following tag columns: ' + \
+               ', '.join(discovery_properties_columns)
     elif discovery_properties_columns is None:
         logger.exception('Missing expected discovery property column(s): %s',
                          set(discovery_properties_columns).difference(proposed_columns))
@@ -134,7 +133,7 @@ def upsert_discovered_records(df: pandas.DataFrame, api_inputs: ApiInputs, disco
     data_frame.Timestamp = data_frame.Timestamp.dt.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
     data_frame = data_frame.rename(columns={'DiscoveredValue': 'CurrentValue'})
 
-    column_dict = {'DiscoveryProperties':discovery_properties_columns + ['Timestamp'],
+    column_dict = {'DiscoveryProperties': discovery_properties_columns + ['Timestamp'],
                    'DeviceTags': device_tag_columns,
                    'SensorTags': sensor_tag_columns,
                    'Metadata': metadata_columns,
@@ -158,7 +157,7 @@ def upsert_discovered_records(df: pandas.DataFrame, api_inputs: ApiInputs, disco
     data_frame = set_properties(raw_df=data_frame, column_dict=column_dict)
     data_frame = data_frame.drop(columns=discovery_properties_columns + ['Timestamp'] + device_tag_columns +
                                          sensor_tag_columns + metadata_columns  # + ontology_tag_columns
-     )
+                                 )
     data_frame = data_frame.assign(OntologyTags=None)
 
     final_req_cols = ['ApiProjectId', 'InstallationId', 'NetworkDeviceId', 'DriverClassName', 'UserId', 'BatchNo',
@@ -188,7 +187,7 @@ def upsert_discovered_records(df: pandas.DataFrame, api_inputs: ApiInputs, disco
             # remove outer [] from json
             discovery_payload = re.sub(r"^[\[]", '', re.sub(r"[\]]$", '', discovery_payload))
 
-            logger.info(f"Upserting discovery record group {name} of {grouped_df.ngroups-1}. ")
+            logger.info(f"Upserting discovery record group {name} of {grouped_df.ngroups - 1}. ")
             response = requests.post(url=url, headers=headers, data=discovery_payload)
 
             response_status = '{} {}'.format(response.status_code, response.reason)
@@ -199,8 +198,8 @@ def upsert_discovered_records(df: pandas.DataFrame, api_inputs: ApiInputs, disco
                 if response.text.startswith('{'):
                     response_content = response.json()
                     chunk_list += [{'Chunk': name, 'response_status': response.status_code,
-                                   'response_reason': response.reason, 'error_code': response_content['ErrorCode'],
-                                   'errors': response_content['Errors']}]
+                                    'response_reason': response.reason, 'error_code': response_content['ErrorCode'],
+                                    'errors': response_content['Errors']}]
                 elif response.text.startswith('"'):
                     chunk_list += [{'Chunk': name, 'response_status': response.status_code,
                                     'response_reason': response.reason, 'errors': response.json()}]
@@ -261,11 +260,12 @@ def upsert_device_sensors(df: pandas.DataFrame, api_inputs: ApiInputs, tag_colum
     Returns
     -------
     tuple[list, pandas.DataFrame]
-        (response_status_list, upsert_response_df) - Returns the list of response statuses and the dataframe containing the parsed response text.
+        (response_status_list, upsert_response_df) - Returns the list of response statuses and the dataframe containing
+        the parsed response text.
 
     """
 
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -427,11 +427,12 @@ def upsert_sites(df: pandas.DataFrame, api_inputs: ApiInputs, tag_columns: list
     Returns
     -------
     tuple[str, pandas.DataFrame]
-        (response, response_data_frame) - Returns the response status and the dataframe containing the parsed response text.
+        (response, response_data_frame) - Returns the response status and the dataframe containing the parsed response
+        text.
 
     """
 
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -502,8 +503,8 @@ def upsert_sites(df: pandas.DataFrame, api_inputs: ApiInputs, tag_columns: list
 
     count_entities = response_data_frame.apply(
         lambda row: 'Created' if (row['IsInserted'] == True and row['IsUpdated'] == False) else (
-            'Updated' if row['IsInserted'] == False and row['IsUpdated'] == True else 'Failed'), axis=1).isin([
-        'Created', 'Updated']).sum()
+            'Updated' if row['IsInserted'] == False and row['IsUpdated'] == True else 'Failed'), axis=1).isin(
+        ['Created', 'Updated']).sum()
 
     _upsert_entities_affected_count(api_inputs=api_inputs, entities_affected_count=count_entities)
     _adx_support(api_inputs=api_inputs, payload_type='Sites')
@@ -580,7 +581,7 @@ def upsert_workorders(df: pandas.DataFrame, api_inputs: ApiInputs, save_addition
 
     data_frame = df.copy()
 
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -703,13 +704,14 @@ def upsert_timeseries_ds(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_t
     Returns
     -------
     tuple[str, pandas.DataFrame]
-        (response_status, response_df) - Returns the response status and the dataframe containing the parsed response text.
+        (response_status, response_df) - Returns the response status and the dataframe containing the parsed response
+        text.
 
     """
 
     data_frame = df.copy()
 
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -829,7 +831,8 @@ def upsert_timeseries_ds(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_t
     # ObjectPropertyId: string, Timestamp: datetime, TimestampId: datetime, TimestampLocal: datetime,
     # TimestampLocalId: datetime, Value: real, DataFeedFileStatusId: string, InstallationId: string, Meta: dynamic
 
-    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/adx/time-series-operation?originalName={name}"
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/adx/time-series-operation?originalName=" \
+          f"{name}"
     logger.info("Sending request: POST %s", url)
 
     logger.info("Sending request to ingest %s files from %s", str(upload_result[1]), upload_result[0])
@@ -877,10 +880,11 @@ def upsert_data(data_frame, api_inputs: ApiInputs, table_name: str, key_columns:
     Returns
     -------
     tuple[str, pandas.DataFrame]
-        (response_status, response_df) - Returns the response status and the dataframe containing the parsed response text.
+        (response_status, response_df) - Returns the response status and the dataframe containing the parsed response
+        text.
 
     """
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -947,10 +951,11 @@ def replace_data(data_frame, api_inputs: ApiInputs, table_name: str):
     Returns
     -------
     tuple[str, pandas.DataFrame]
-        (response_status, response_df) - Returns the response status and the dataframe containing the parsed response text.
+        (response_status, response_df) - Returns the response status and the dataframe containing the parsed response
+        text.
 
     """
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -1008,11 +1013,12 @@ def append_data(data_frame, api_inputs: ApiInputs, table_name: str):
     Returns
     -------
     tuple[str, pandas.DataFrame]
-        (response_status, response_df) - Returns the response status and the dataframe containing the parsed response text.
+        (response_status, response_df) - Returns the response status and the dataframe containing the parsed response
+        text.
 
     """
     # payload = {}
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -1071,7 +1077,7 @@ def upsert_file_row_count(api_inputs: ApiInputs, row_count: int):
     if row_count is None:
         row_count = 0
 
-    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+    if api_inputs.api_base_url == '' or api_inputs.bearer_token == '':
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -1096,3 +1102,49 @@ def upsert_file_row_count(api_inputs: ApiInputs, row_count: int):
         return response_status
 
     return response_status
+
+
+def upsert_event_work_order_id(api_inputs: ApiInputs, event_task_id: uuid.UUID, integration_id: str,
+                               work_order_status: str):
+    """
+
+    Parameters
+    ----------
+    api_inputs : ApiInputs
+        Object returned by initialize() function.
+    event_task_id : uuid.UUID
+        The value of the `work_order_input['EventTaskId']`
+    integration_id : str
+        The 3rd Party work order system's unique identifier for the work order
+    work_order_status : str
+        The status of the work order
+
+    Returns
+    -------
+    (str, str)
+        response_status, response.text - The response status of the call and the text from the response body.
+
+    """
+
+    if api_inputs.api_projects_endpoint == '' or api_inputs.bearer_token == '':
+        logger.error("You must call initialize() before using API.")
+        return 'Error', 'You must call initialize() before using the API.'
+
+    header = api_inputs.api_headers.default
+
+    payload = {
+                  "IntegrationId": integration_id,
+                  "Status": status
+    }
+
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/events/{str(event_task_id)}/work-order"
+
+    response = requests.put(url=url, data=payload, headers=headers)
+    response_status = '{} {}'.format(response.status_code, response.reason)
+    if response.status_code != 200:
+        logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
+                     response.reason)
+        return response_status, response.text
+
+    return response_status, response.text
+
