@@ -68,12 +68,12 @@ functions for retrieving details of existing tasks on the Switch Automation plat
 """
 
 from .pipeline import (IntegrationTask, QueueTask, LogicModuleTask, AnalyticsTask, DiscoverableIntegrationTask,
-                       logger)  # , EventWorkOrderTask
+                       EventWorkOrderTask, logger)
 from .automation import Automation
 from .definitions import (IntegrationDeviceConfigPropertyDefinition, IntegrationDeviceDefinition,
-                          DiscoveryIntegrationInput, BaseProperty, AnalyticsSettings)  # , EventWorkOrderFieldDefinition
+                          AnalyticsSettings, EventWorkOrderFieldDefinition, IntegrationSettings)
 
 __all__ = ['IntegrationTask', 'QueueTask', 'LogicModuleTask', 'AnalyticsTask', 'DiscoverableIntegrationTask',
-           'Automation', 'logger', 'IntegrationDeviceConfigPropertyDefinition',
-           'IntegrationDeviceDefinition', 'DiscoveryIntegrationInput', 'BaseProperty',
-           'AnalyticsSettings']  # 'EventWorkOrderTask', 'EventWorkOrderFieldDefinition',
+           'EventWorkOrderTask','Automation', 'logger', 'IntegrationDeviceConfigPropertyDefinition',
+           'IntegrationDeviceDefinition', 'EventWorkOrderFieldDefinition',
+           'AnalyticsSettings', 'IntegrationSettings']
