@@ -78,13 +78,13 @@ import datetime
 from typing import List
 from abc import ABC, abstractmethod
 # from azure.servicebus import ServiceBusClient, ServiceBusReceiveMode  # , ServiceBusMessage
-from .._utils._utils import ApiInputs, DiscoveryIntegrationInput # , _is_valid_regex, generate_password, _column_name_cap, DataFeedFileProcessOutput
-from .._utils._constants import (MAPPING_ENTITIES  #, api_prefix, argus_prefix, EXPECTED_DELIVERY, DEPLOY_TYPE,
+from .._utils._utils import ApiInputs, DiscoveryIntegrationInput  # , _is_valid_regex, generate_password, _column_name_cap, DataFeedFileProcessOutput
+from .._utils._constants import (MAPPING_ENTITIES  # , api_prefix, argus_prefix, EXPECTED_DELIVERY, DEPLOY_TYPE,
                                  # QUEUE_NAME, ERROR_TYPE, SCHEDULE_TIMEZONE)
                                  )
 from ..integration.helpers import get_templates, get_units_of_measure
-from .definitions import (IntegrationDeviceDefinition, EventWorkOrderFieldDefinition, BaseProperty, AnalyticsSettings,
-                          IntegrationSettings)  #, DeviceTypeDefinition
+from .definitions import (IntegrationDeviceDefinition, EventWorkOrderFieldDefinition, AnalyticsSettings, # BaseProperty
+                          IntegrationSettings)  # , DeviceTypeDefinition
 # from .._utils._platform import _get_ingestion_connection_string
 # from io import StringIO
 
@@ -191,9 +191,9 @@ class IntegrationTask(Task):
         Parameters
         ----------
         api_inputs: ApiInputs
-            object returned by call to initialize()
-        stream to process :
-            details of the stream to be processed.
+            The object returned by call to initialize()
+        stream_to_process
+            The details of the stream to be processed.
         """
         pass
 
@@ -257,8 +257,8 @@ class DiscoverableIntegrationTask(Task):
                 required_integration_keys.add(setting.property_name)
 
         if not required_integration_keys.issubset(set(integration_settings.keys())):
-            sw.pipeline.logger.error(f'The integration_settings passed to the task do not contain the required keys: '
-                                     f'{required_integration_keys} ')
+            logger.error(f'The integration_settings passed to the task do not contain the required keys: '
+                         f'{required_integration_keys} ')
             return False
         else:
             return True
@@ -342,16 +342,16 @@ class EventWorkOrderTask(Task):
             display_label - the display label for the given property_name in Task Insights UI
             editor - the editor shown in Task Insights UI
             default_value - default value for this property_name (if applicable)
-            allowed_values - the set of allowed values (if applicable) for the given property_name. If editor=text_box, this
-            should be None.
+            allowed_values - the set of allowed values (if applicable) for the given property_name. If editor=text_box,
+            this should be None.
 
         """
         pass
 
     def check_work_order_input_valid(self, work_order_input: dict):
-        required_work_order_input_keys = set('task_id')
+        required_work_order_input_keys = set(['EventTaskId', 'Description', 'IntegrationId', 'DueDate'])
 
-        for setting in self.work_order_field_definitions:
+        for setting in self.work_order_fields_definition:
             required_work_order_input_keys.add(setting.property_name)
 
         if not required_work_order_input_keys.issubset(set(work_order_input.keys())):
@@ -361,6 +361,19 @@ class EventWorkOrderTask(Task):
         else:
             return True
 
+    def check_integration_settings_valid(self, integration_settings: dict):
+        required_integration_keys = set()
+
+        for setting in self.integration_settings_definition:
+            required_integration_keys.add(setting.property_name)
+
+        if not required_integration_keys.issubset(set(integration_settings.keys())):
+            logger.error(f'The analytics_setting passed to the task do not contain the required keys: '
+                         f'{required_integration_keys} ')
+            return False
+        else:
+            return True
+
     @abstractmethod
     def generate_work_order(self, api_inputs: ApiInputs, integration_settings: dict, work_order_input: dict):
         """Generate work order in 3rd party system via Events UI
@@ -368,6 +381,21 @@ class EventWorkOrderTask(Task):
         Method to generate work order in 3rd party system based on a work order task created in Events UI in the Switch
         Automation platform.
 
+        Notes
+        -----
+        In addition to the defined `work_order_fields_definition` fields, the `work_order_input` dictionary passed to
+        this method will contain the following keys:
+
+        - `EventTaskId`
+            - unique identifier (uuid.UUID) for the given record in the Switch Automation platform
+        - `Description`
+            - free text field describing the work order to be generated.
+        - `IntegrationId`
+            - if linked to an existing work order in the 3rd party API, this will contain that system's identifier for
+            the workorder. If generating a net new workorder, this field will be null (None).
+        - `DueDate`
+            - The due date for the work order as set in the Switch Automation platform.
+
         Parameters
         ----------
         api_inputs: ApiInputs
@@ -384,16 +412,14 @@ class EventWorkOrderTask(Task):
 
 
 class QueueTask(Task):
-    """Integration Task
+    """Queue Task
 
     This class is used to create integrations that post data to the Switch Automation platform using a Queue as the
     data source.
 
     Only one of the following methods should be implemented per class, based on the type of integration required:
 
-    - process_file()
-    - process_stream()
-    - process()
+    - process_queue()
 
     """
 
@@ -438,23 +464,37 @@ class QueueTask(Task):
 
 class AnalyticsTask(Task):
 
-    # @property
-    # @abstractmethod
-    # def analytics_settings_definition(self) -> List[AnalyticsSettings]:
-    #     """Define the start() method's analytics_settings dictionary requirements & defaults.
-    #
-    #     The definition of the dictionary keys, display labels in Task Insights UI, default value & allowed values
-    #     for the start() method's ``analytics_settings`` input parameter.
-    #
-    #     PropertyName - the analytics_settings dictionary key
-    #     DisplayLabel - the display label for the given property_name in Task Insights UI
-    #     Editor - the editor shown in Task Insights UI
-    #     DefaultValue - default value for this property_name (if applicable)
-    #     AllowedValues - the set of allowed values (if applicable) for the given property_name. If editor=text_box, this
-    #     should be None.
-    #
-    #     e.g. AnalyticsSettings(property_name='')
-    #     """
+    @property
+    @abstractmethod
+    def analytics_settings_definition(self) -> List[AnalyticsSettings]:
+        """Define the start() method's analytics_settings dictionary requirements & defaults.
+
+        The definition of the dictionary keys, display labels in Task Insights UI, default value & allowed values
+        for the start() method's ``analytics_settings`` input parameter.
+
+        property_name - the analytics_settings dictionary key
+        display_label - the display label for the given property_name in Task Insights UI
+        editor - the editor shown in Task Insights UI
+        default_value - default value for this property_name (if applicable)
+        allowed_values - the set of allowed values (if applicable) for the given property_name. If editor=text_box, this
+        should be None.
+
+        """
+        pass
+
+    def check_analytics_settings_valid(self, analytics_settings: dict):
+        # required_analytics_settings_keys = set(['task_id'])
+        required_analytics_settings_keys= set()
+
+        for setting in self.analytics_settings_definition:
+            required_analytics_settings_keys.add(setting.property_name)
+
+        if not required_analytics_settings_keys.issubset(set(analytics_settings.keys())):
+            logger.error(f'The analytics_setting passed to the task do not contain the required keys: '
+                         f'{required_analytics_settings_keys} ')
+            return False
+        else:
+            return True
 
     @abstractmethod
     def start(self, api_inputs: ApiInputs, analytics_settings: dict):
@@ -462,6 +502,14 @@ class AnalyticsTask(Task):
 
         The method should contain all code used by the task.
 
+        Notes
+        -----
+        The method should first check the analytics_settings passed to the task are valid. Pseudo code below:
+         >>> if self.check_analytics_settings_valid(analytics_settings=analytics_settings == True:
+         >>>    # Your actual task code here - i.e. proceed with the task if valid analytics_settings passed.
+         >>> else:
+         >>>    sw.pipeline.logger.error('Invalid analytics_settings passed to driver. ')
+
         Parameters
         ----------
         api_inputs : ApiInputs
