@@ -7,6 +7,6 @@
 A module for interacting with the insights platform services, etc of the Switch Automation platform.
 """
 
-from .platform_insights import get_current_insights_by_equipment
+# from .platform_insights import get_current_insights_by_equipment
 
-__all__ = ['get_current_insights_by_equipment']
+# __all__ = ['get_current_insights_by_equipment']
